==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/ProfileEnrollmentPolicyRuleActivationRequirement.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Contains a single Boolean property that indicates whether &#x60;emailVerification&#x60; should occur
 * (&#x60;true&#x60;) or not (&#x60;false&#x60;, default)
 */
@ApiModel(description = "Contains a single Boolean property that indicates whether `emailVerification` should occur (`true`) or not (`false`, default)")
@JsonPropertyOrder({ ProfileEnrollmentPolicyRuleActivationRequirement.JSON_PROPERTY_EMAIL_VERIFICATION })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ProfileEnrollmentPolicyRuleActivationRequirement implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EMAIL_VERIFICATION = "emailVerification";
    private Boolean emailVerification;

    public ProfileEnrollmentPolicyRuleActivationRequirement() {
    }

    public ProfileEnrollmentPolicyRuleActivationRequirement emailVerification(Boolean emailVerification) {

        this.emailVerification = emailVerification;
        return this;
    }

    /**
     * Get emailVerification
     *
     * @return emailVerification
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_EMAIL_VERIFICATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getEmailVerification() {
        return emailVerification;
    }

    @JsonProperty(JSON_PROPERTY_EMAIL_VERIFICATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEmailVerification(Boolean emailVerification) {
        this.emailVerification = emailVerification;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ProfileEnrollmentPolicyRuleActivationRequirement profileEnrollmentPolicyRuleActivationRequirement = (ProfileEnrollmentPolicyRuleActivationRequirement) o;
        return Objects.equals(this.emailVerification,
                profileEnrollmentPolicyRuleActivationRequirement.emailVerification);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(emailVerification);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ProfileEnrollmentPolicyRuleActivationRequirement {\n");
        sb.append("    emailVerification: ").append(toIndentedString(emailVerification)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/ProfileEnrollmentPolicyRuleActivationRequirement.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Contains a single Boolean property that indicates whether &#x60;emailVerification&#x60; should occur
 * (&#x60;true&#x60;) or not (&#x60;false&#x60;, default)
 */
@ApiModel(description = "Contains a single Boolean property that indicates whether `emailVerification` should occur (`true`) or not (`false`, default)")
@JsonPropertyOrder({ ProfileEnrollmentPolicyRuleActivationRequirement.JSON_PROPERTY_EMAIL_VERIFICATION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ProfileEnrollmentPolicyRuleActivationRequirement implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EMAIL_VERIFICATION = "emailVerification";
    private Boolean emailVerification;

    public ProfileEnrollmentPolicyRuleActivationRequirement() {
    }

    public ProfileEnrollmentPolicyRuleActivationRequirement emailVerification(Boolean emailVerification) {

        this.emailVerification = emailVerification;
        return this;
    }

    /**
     * Get emailVerification
     *
     * @return emailVerification
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_EMAIL_VERIFICATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getEmailVerification() {
        return emailVerification;
    }

    @JsonProperty(JSON_PROPERTY_EMAIL_VERIFICATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEmailVerification(Boolean emailVerification) {
        this.emailVerification = emailVerification;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ProfileEnrollmentPolicyRuleActivationRequirement profileEnrollmentPolicyRuleActivationRequirement = (ProfileEnrollmentPolicyRuleActivationRequirement) o;
        return Objects.equals(this.emailVerification,
                profileEnrollmentPolicyRuleActivationRequirement.emailVerification);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(emailVerification);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ProfileEnrollmentPolicyRuleActivationRequirement {\n");
        sb.append("    emailVerification: ").append(toIndentedString(emailVerification)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
